@@ -22,8 +22,6 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 
-#ifdef USECLAM
-
 //Init Clamav scanner engine
 bool ClamLibScanner::InitDatabase()
 {
@@ -73,7 +71,34 @@ bool ClamLibScanner::ReloadDatabase()
    //PSE: if(cl_statchkdir(&dbstat) == 1)
     if(cl_statchkdir(&dbstat) != 0)
     {
-        cl_statfree(&dbstat);
+
+	int ret=0;
+	unsigned int no=0;
+
+	cl_free(root);
+	root = NULL;
+
+	if ((ret = cl_loaddbdir(cl_retdbdir(), &root, &no)))
+	{
+	LogFile::ErrorMessage ("Database reload error: %s\n", cl_perror(ret));
+	return false;
+	}
+	if ((ret = cl_build(root)))
+	{
+	LogFile::ErrorMessage ("Database reload initialization error: %s\n", cl_perror(ret));
+	cl_free(root);
+	return false;
+	}
+
+	LogFile::ErrorMessage ("Database reloaded with %d signatures\n", no);
+
+	cl_statfree(&dbstat);
+	memset(&dbstat, 0, sizeof(struct cl_stat));
+	cl_statinidir(cl_retdbdir(), &dbstat);
+
+/*
+//CH 
+       cl_statfree(&dbstat);
 
         LogFile::ErrorMessage ("Reload Database\n" );
         if ( InitDatabase() == false)
@@ -81,6 +106,7 @@ bool ClamLibScanner::ReloadDatabase()
             LogFile::ErrorMessage ("Reload Database - failed\n" );
             return false;
         }
+*/
     }
 
     return true;
@@ -101,12 +127,8 @@ int ClamLibScanner::Scanning( )
     {
         LogFile::ErrorMessage ("Could not open file to scan: %s\n", FileName );
         ScannerAnswer="Could not open file to scan";
-//PSEstart
-	//PSE: We are child but parent process wants this answer to know!
-    	WriteScannerAnswer();
-//PSEend
         close(fd);
-        exit (2);
+        return 1;
     }
 
     //Wait till file is set up for scanning
@@ -118,12 +140,8 @@ int ClamLibScanner::Scanning( )
         LogFile::ErrorMessage ("Virus %s in file %s detected!\n", virname, FileName );
 
         ScannerAnswer=virname;
-//PSEstart
-	//PSE: We are child but parent process wants this answer to know!
-    	WriteScannerAnswer();
-//PSEend
         close(fd);
-        exit (1);
+        return 1;
     }
     else
     {
@@ -131,23 +149,14 @@ int ClamLibScanner::Scanning( )
         {
             LogFile::ErrorMessage ("Error Virus scanner: %s %s\n", FileName, cl_perror(ret) );
             ScannerAnswer= cl_perror(ret);
-//PSEstart
-	//PSE: We are child but parent process wants this answer to know!
-    	WriteScannerAnswer();
-//PSEend
             close(fd);
-            exit (2);
+            return 2;
         }
     }
 
     close(fd);
     ScannerAnswer="Clean";
-//PSEstart
-    //PSE: We are child but parent process wants this answer to know!
-    WriteScannerAnswer();
-//PSEend
-
-    exit (0);
+    return 0;
 }
 
 
@@ -166,20 +175,30 @@ bool ClamLibScanner::InitSelfEngine()
 
 int ClamLibScanner::ScanningComplete()
 {
-
-    int status=0;
+    int ret;
+    char p_read[2];
+    memset(&p_read, 0, sizeof(p_read));
 
     UnlockFile();
 
-    //Wait till scanning is complete
-    waitpid( ScannerPid, &status, 0);
+    //Wait till scanner finishes with the file
+    while ((ret = read(commin[0], &p_read, 1)) < 0)
+    {
+    	if (errno == EINTR) continue;
+    	if (errno != EPIPE) LogFile::ErrorMessage("cl1 read to pipe failed: %s\n", strerror(errno));
 
-    //Delete scanned file
-    DeleteFile();
+    	DeleteFile();
+    	exit(0);
+    }
 
-    //Virus found ? 0=No ; -1=Yes; -2=Scanfail
-    return WEXITSTATUS(status);
+    //Truncate and reuse existing tempfile
+    if (ReinitFile() == false)
+    {
+    	LogFile::ErrorMessage("ReinitFile() failed\n");
+    }
 
+    //Virus found ? 0=No ; 1=Yes; 2=Scanfail
+    return (int)atoi(p_read);
 }
 
 //PSEstart
@@ -204,4 +223,3 @@ ClamLibScanner::~ClamLibScanner()
 {
 }
 
-#endif
