@@ -69,6 +69,12 @@ string ConnectionToBrowser::PrepareHeaderForServer()
         } else if ( it->find( "Keep-Alive", 0 ) == 0 )
         {
             continue;
+        } else if ( it->find( "Range:", 0 ) == 0 )
+        {
+            continue;
+        } else if ( it->find( "If-Range", 0 ) == 0 )
+	{
+            continue;
         } else if (( it->find( "Accept-Encoding", 0 ) && NOENCODING ) == 0 )
         {
             continue;
