@@ -41,10 +41,6 @@ protected:
 
 vector <string> tokens;
 
-string Request;
-
-string Host;
-
 virtual bool AnalyseHeaderLine( string *RequestT ) = 0;
 
 public: 
