@@ -31,7 +31,8 @@
 #include <deque>
 #include <stdlib.h>
 #include <errno.h>
-
+#include <sys/types.h>
+#include <signal.h>
 
 using namespace std;
 
@@ -40,6 +41,8 @@ class ProxyHandler {
 
 private:
 
+bool newinstance;
+
 bool HeaderSend;
 
 bool BrowserDropped;
